@@ -1,7 +1,7 @@
 # Install and start **Searchlight** service
 
 # To enable Searchlight services, add the following to localrc
-# enable_plugin searchlight http://git.openstack.org/openstack/searchlight
+# enable_plugin searchlight https://opendev.org/openstack/searchlight
 # enable_service searchlight-api
 # enable_service searchlight-listener
 
@@ -34,6 +34,12 @@ SEARCHLIGHT_CONF=$SEARCHLIGHT_CONF_DIR/searchlight.conf
 SEARCHLIGHT_LOG_DIR=/var/log/searchlight
 SEARCHLIGHT_AUTH_CACHE_DIR=${SEARCHLIGHT_AUTH_CACHE_DIR:-/var/cache/searchlight}
 SEARCHLIGHT_APIPASTE_CONF=$SEARCHLIGHT_CONF_DIR/api-paste.ini
+SEARCHLIGHT_UWSGI_CONF=$SEARCHLIGHT_CONF_DIR/searchlight-uwsgi.ini
+SEARCHLIGHT_UWSGI_APP=$SEARCHLIGHT_BIN_DIR/searchlight-api-wsgi
+
+if is_service_enabled tls-proxy; then
+    SEARCHLIGHT_SERVICE_PROTOCOL="https"
+fi
 
 # Public IP/Port Settings
 SEARCHLIGHT_SERVICE_PROTOCOL=${SEARCHLIGHT_SERVICE_PROTOCOL:-$SERVICE_PROTOCOL}
@@ -42,12 +48,10 @@ SEARCHLIGHT_SERVICE_PORT=${SEARCHLIGHT_SERVICE_PORT:-9393}
 SEARCHLIGHT_SERVICE_PORT_INT=${SEARCHLIGHT_SERVICE_PORT_INT:-19393}
 
 ELASTICSEARCH_VERSION=${ELASTICSEARCH_VERSION:-2.3.4}
-ELASTICSEARCH_BASEURL=${ELASTICSEARCH_BASEURL:-https://download.elastic.co/elasticsearch/release/org/elasticsearch/distribution}
-ELASTICSEARCH_BASEURL_DEB=${ELASTICSEARCH_BASEURL}/deb/elasticsearch
-ELASTICSEARCH_BASEURL_RPM=${ELASTICSEARCH_BASEURL}/rpm/elasticsearch
-
-# Tell Tempest this project is present
-TEMPEST_SERVICES+=,searchlight
+# Base URL for ElasticSearch 5.x and 6.x
+ELASTICSEARCH_BASEURL=https://artifacts.elastic.co/downloads/elasticsearch
+# Base URL for ElasticSearch 2.x
+ELASTICSEARCH_BASEURL_LEGACY=https://download.elastic.co/elasticsearch/release/org/elasticsearch/distribution
 
 # Helper Functions
 # ----------------
@@ -72,6 +76,7 @@ function setup_colorized_logging_searchlight {
 function cleanup_searchlight {
     _stop_elasticsearch
     sudo rm -rf $SEARCHLIGHT_STATE_PATH $SEARCHLIGHT_AUTH_CACHE_DIR
+    sudo rm -f $(apache_site_config_for searchlight_api)
 }
 
 # configure_searchlight - Set config files, create data dirs, etc
@@ -91,21 +96,18 @@ function configure_searchlight {
     iniset $SEARCHLIGHT_CONF DEFAULT debug $ENABLE_DEBUG_LOG_LEVEL
     iniset $SEARCHLIGHT_CONF DEFAULT state_path $SEARCHLIGHT_STATE_PATH
 
-    # Install the policy file for the API server
-    cp $SEARCHLIGHT_DIR/etc/policy.json $SEARCHLIGHT_CONF_DIR/policy.json
-    iniset $SEARCHLIGHT_CONF DEFAULT policy_file $SEARCHLIGHT_CONF_DIR/policy.json
-
     # API Configuration
     sudo cp $SEARCHLIGHT_DIR/etc/api-paste.ini $SEARCHLIGHT_APIPASTE_CONF
-    iniset $SEARCHLIGHT_CONF api public_endpoint $SEARCHLIGHT_SERVICE_PROTOCOL://$SEARCHLIGHT_SERVICE_HOST:$SEARCHLIGHT_SERVICE_PORT/
+    iniset $SEARCHLIGHT_CONF api public_endpoint $SEARCHLIGHT_SERVICE_PROTOCOL://$SEARCHLIGHT_SERVICE_HOST/search
 
     # OpenStack users
-    # FIXME(ekarlso): Make this configurable to support ks v3 also
-    iniset $SEARCHLIGHT_CONF service_credentials auth_plugin password
+    iniset $SEARCHLIGHT_CONF service_credentials auth_type password
     iniset $SEARCHLIGHT_CONF service_credentials username searchlight
-    iniset $SEARCHLIGHT_CONF service_credentials tenant_name $SERVICE_TENANT_NAME
+    iniset $SEARCHLIGHT_CONF service_credentials user_domain_id default
+    iniset $SEARCHLIGHT_CONF service_credentials project_domain_id default
     iniset $SEARCHLIGHT_CONF service_credentials password $SERVICE_PASSWORD
-    iniset $SEARCHLIGHT_CONF service_credentials auth_url $KEYSTONE_AUTH_URI/v2.0
+    iniset $SEARCHLIGHT_CONF service_credentials project_name $SERVICE_PROJECT_NAME
+    iniset $SEARCHLIGHT_CONF service_credentials auth_url $KEYSTONE_SERVICE_URI
     iniset $SEARCHLIGHT_CONF service_credentials os_region_name $REGION_NAME
 
     # Keystone Middleware
@@ -137,10 +139,29 @@ function configure_searchlight {
     iniset $SEARCHLIGHT_CONF resource_plugin:os_designate_zone enabled False
     iniset $SEARCHLIGHT_CONF resource_plugin:os_designate_recordset enabled False
 
+    # Plugin config - disable ironic by default since it's not typically installed
+    iniset $SEARCHLIGHT_CONF resource_plugin:os_ironic_chassis enabled False
+    iniset $SEARCHLIGHT_CONF resource_plugin:os_ironic_chassis notifications_topics_exchanges ironic_versioned_notifications,ironic
+    iniset $SEARCHLIGHT_CONF resource_plugin:os_ironic_node enabled False
+    iniset $SEARCHLIGHT_CONF resource_plugin:os_ironic_node notifications_topics_exchanges ironic_versioned_notifications,ironic
+    iniset $SEARCHLIGHT_CONF resource_plugin:os_ironic_port enabled False
+    iniset $SEARCHLIGHT_CONF resource_plugin:os_ironic_port notifications_topics_exchanges ironic_versioned_notifications,ironic
+
+    # Plugin config - enable versioned notifications for flavor
+    iniset $SEARCHLIGHT_CONF resource_plugin:os_nova_flavor enabled True
+    iniset $SEARCHLIGHT_CONF resource_plugin:os_nova_flavor notifications_topics_exchanges versioned_notifications,nova
+
+    iniset $SEARCHLIGHT_CONF resource_plugin:os_nova_server enabled True
+    iniset $SEARCHLIGHT_CONF resource_plugin:os_nova_server notifications_topics_exchanges versioned_notifications,nova
+    iniset $SEARCHLIGHT_CONF resource_plugin:os_nova_server use_versioned_notifications True
+
     # Plugin config - disable swift by default since it's not typically installed
     iniset $SEARCHLIGHT_CONF resource_plugin:os_swift_account enabled False
     iniset $SEARCHLIGHT_CONF resource_plugin:os_swift_container enabled False
     iniset $SEARCHLIGHT_CONF resource_plugin:os_swift_object enabled False
+
+    # uWSGI configuration
+    write_uwsgi_config "$SEARCHLIGHT_UWSGI_CONF" "$SEARCHLIGHT_UWSGI_APP" "/search"
 }
 
 # create_searchlight_accounts - Set up common required searchlight accounts
@@ -156,9 +177,9 @@ function create_searchlight_accounts {
             get_or_create_service "searchlight" "search" "Searchlight Service"
             get_or_create_endpoint "search" \
                 "$REGION_NAME" \
-                "$SEARCHLIGHT_SERVICE_PROTOCOL://$SEARCHLIGHT_SERVICE_HOST:$SEARCHLIGHT_SERVICE_PORT/" \
-                "$SEARCHLIGHT_SERVICE_PROTOCOL://$SEARCHLIGHT_SERVICE_HOST:$SEARCHLIGHT_SERVICE_PORT/" \
-                "$SEARCHLIGHT_SERVICE_PROTOCOL://$SEARCHLIGHT_SERVICE_HOST:$SEARCHLIGHT_SERVICE_PORT/"
+                "$SEARCHLIGHT_SERVICE_PROTOCOL://$SEARCHLIGHT_SERVICE_HOST/search" \
+                "$SEARCHLIGHT_SERVICE_PROTOCOL://$SEARCHLIGHT_SERVICE_HOST/search" \
+                "$SEARCHLIGHT_SERVICE_PROTOCOL://$SEARCHLIGHT_SERVICE_HOST/search"
         fi
     fi
 }
@@ -175,13 +196,29 @@ function init_searchlight {
     $SEARCHLIGHT_BIN_DIR/searchlight-manage --config-file $SEARCHLIGHT_CONF index sync --force
 }
 
+# Install Searchlight's requirements
+# See https://elasticsearch-py.readthedocs.io/en/master/#compatibility
+function _setup_searchlight_dev {
+    setup_develop $SEARCHLIGHT_DIR
+    if [[ $ELASTICSEARCH_VERSION =~ ^5 ]]; then
+        echo "Installing python elasticsearch for ES 5.x"
+        $REQUIREMENTS_DIR/.venv/bin/edit-constraints $REQUIREMENTS_DIR/upper-constraints.txt elasticsearch
+        pip_install -U -r $SEARCHLIGHT_DIR/elasticsearch5.txt
+    elif [[ $ELASTICSEARCH_VERSION =~ ^6 ]]; then
+        echo "WARNING - Searchlight is not tested with ES 6.x!!!"
+        # echo "Installing python elasticsearch for ES 6.x"
+        # $REQUIREMENTS_DIR/.venv/bin/edit-constraints $REQUIREMENTS_DIR/upper-constraints.txt eleasticsearch
+        # pip install -c $REQUIREMENTS_DIR/upper-constraints.txt -U -r $SEARCHLIGHT_DIR/elasticsearch6.txt
+    fi
+}
+
 # install_searchlight - Collect source and prepare
 function install_searchlight {
     git_clone $SEARCHLIGHT_REPO $SEARCHLIGHT_DIR $SEARCHLIGHT_BRANCH
-    setup_develop $SEARCHLIGHT_DIR
-  
+    _setup_searchlight_dev
     _download_elasticsearch
     _install_elasticsearch
+    pip_install uwsgi
 }
 
 # install_searchlightclient - Collect source and prepare
@@ -193,12 +230,7 @@ function install_searchlightclient {
 # start_searchlight - Start running processes, including screen
 function start_searchlight {
     if is_service_enabled searchlight-api; then
-        run_process searchlight-api "$SEARCHLIGHT_BIN_DIR/searchlight-api --config-file $SEARCHLIGHT_CONF"
-
-        # Start proxies if enabled
-        if is_service_enabled searchlight-api && is_service_enabled tls-proxy; then
-            start_tls_proxy '*' $SEARCHLIGHT_SERVICE_PORT $SEARCHLIGHT_SERVICE_HOST $SEARCHLIGHT_SERVICE_PORT_INT &
-        fi
+        run_process searchlight-api "$SEARCHLIGHT_BIN_DIR/uwsgi --ini $SEARCHLIGHT_UWSGI_CONF"
     fi
     if is_service_enabled searchlight-listener; then
         run_process searchlight-listener "$SEARCHLIGHT_BIN_DIR/searchlight-listener --config-file $SEARCHLIGHT_CONF"
@@ -210,6 +242,7 @@ function stop_searchlight {
     # Kill the searchlight screen windows
     stop_process searchlight-api
     stop_process searchlight-listener
+    remove_uwsgi_config "$SEARCHLIGHT_UWSGI_CONF" "$SEARCHLIGHT_UWSGI_APP"
 }
 
 
@@ -244,12 +277,25 @@ function _wget_elasticsearch {
 }
 
 function _download_elasticsearch {
-    echo "Downloading elasticsearch"
     if is_ubuntu; then
-        _wget_elasticsearch $ELASTICSEARCH_BASEURL_DEB/${ELASTICSEARCH_VERSION} elasticsearch-${ELASTICSEARCH_VERSION}.deb
+        arch="deb"
     elif is_fedora; then
-        _wget_elasticsearch $ELASTICSEARCH_BASEURL_RPM/${ELASTICSEARCH_VERSION} elasticsearch-${ELASTICSEARCH_VERSION}.rpm
+        arch="rpm"
+    else
+        echo "Unknown architecture; can't download ElasticSearch"
     fi
+    ELASTICSEARCH_FILENAME=elasticsearch-${ELASTICSEARCH_VERSION}.${arch}
+
+    if [[ $ELASTICSEARCH_VERSION =~ ^2 ]]; then
+        ELASTICSEARCH_URL=${ELASTICSEARCH_BASEURL_LEGACY}/${arch}/elasticsearch/${ELASTICSEARCH_VERSION}
+    elif [[ $ELASTICSEARCH_VERSION =~ ^5 ]]; then
+        ELASTICSEARCH_URL=${ELASTICSEARCH_BASEURL}
+    else
+        echo "Current Searchlight only supports ElasticSearch 2.x and 5.x"
+    fi
+    echo "Downloading ElasticSearch $ELASTICSEARCH_VERSION"
+    echo "ElasticSearch URL is $ELASTICSEARCH_URL"
+    _wget_elasticsearch $ELASTICSEARCH_URL $ELASTICSEARCH_FILENAME
 }
 
 function _check_elasticsearch_ready {
@@ -268,7 +314,7 @@ function _start_elasticsearch {
         sudo /bin/systemctl start elasticsearch.service
         _check_elasticsearch_ready
     else
-        echo "Unsupported architecture...can not start elasticsearch."
+        echo "Unsupported architecture... Can not start elasticsearch."
     fi
 }
 
@@ -284,20 +330,23 @@ function _stop_elasticsearch {
 }
 
 function _install_elasticsearch {
-    echo "Installing elasticsearch"
-    pip_install_gr elasticsearch
+    # echo "Installing elasticsearch"
+    # pip_install_gr elasticsearch
     if is_package_installed elasticsearch; then
         echo "Note: elasticsearch was already installed."
         return
     fi
     if is_ubuntu; then
-        is_package_installed openjdk-7-jre-headless || install_package openjdk-7-jre-headless
-
+        if [[ ${DISTRO} == "bionic" ]]; then
+            is_package_installed openjdk-8-jdk-headless || install_package openjdk-8-jdk-headless
+        else
+            is_package_installed default-jdk-headless || install_package default-jdk-headless
+        fi
         sudo dpkg -i ${FILES}/elasticsearch-${ELASTICSEARCH_VERSION}.deb
         sudo update-rc.d elasticsearch defaults 95 10
     elif is_fedora; then
         is_package_installed java-1.8.0-openjdk-headless || install_package java-1.8.0-openjdk-headless
-        yum_install ${FILES}/elasticsearch-${ELASTICSEARCH_VERSION}.noarch.rpm
+        yum_install ${FILES}/elasticsearch-${ELASTICSEARCH_VERSION}.rpm
         sudo /bin/systemctl daemon-reload
         sudo /bin/systemctl enable elasticsearch.service
     else
