@@ -15,6 +15,7 @@
 
 from oslo_config import cfg
 
+from searchlight.common import resource_types
 from searchlight.elasticsearch.plugins import base
 from searchlight.elasticsearch.plugins.swift import get_swift_objects
 from searchlight.elasticsearch.plugins.swift import serialize_swift_object
@@ -34,11 +35,11 @@ class ObjectIndex(base.IndexBase):
 
     @classmethod
     def parent_plugin_type(cls):
-        return "OS::Swift::Container"
+        return resource_types.SWIFT_CONTAINER
 
     @classmethod
     def get_document_type(cls):
-        return 'OS::Swift::Object'
+        return resource_types.SWIFT_OBJECT
 
     def get_mapping(self):
         return {
@@ -73,6 +74,11 @@ class ObjectIndex(base.IndexBase):
             },
             "_parent": {
                 "type": self.parent_plugin_type()
+            },
+            "_meta": {
+                "account_id": {
+                    "resource_type": resource_types.SWIFT_ACCOUNT
+                }
             }
         }
 
@@ -84,6 +90,14 @@ class ObjectIndex(base.IndexBase):
     def is_plugin_enabled_by_default(cls):
         return False
 
+    @property
+    def resource_allowed_policy_target(self):
+        return None
+
+    @property
+    def service_type(self):
+        return None
+
     def _get_rbac_field_filters(self, request_context):
 
         tenant_member = request_context.tenant + ":*"
@@ -97,24 +111,16 @@ class ObjectIndex(base.IndexBase):
                 "has_parent": {
                     "type": self.parent_plugin_type(),
                     "query": {
-                        "filtered": {
-                            "query": {"match_all": {}},
-                            "filter": {
-                                "or": [
-                                    {
-                                        'term': {
-                                            'account_id': account_id
-                                        }
-                                    },
-                                    {
-                                        'terms': {
-                                            'x-container-read': [
-                                                tenant_member,
-                                                single_user]
-                                        }
-                                    },
-                                ]
-                            }
+                        "bool": {
+                            "should": [
+                                {'term': {'account_id': account_id}},
+                                {'terms': {
+                                    'x-container-read': [
+                                        tenant_member,
+                                        single_user
+                                    ]
+                                }}
+                            ]
                         }
                     }
                 }
